==> ec2-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/GatewayVpcEndpoint.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A gateway VPC endpoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:19:46.999Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.GatewayVpcEndpoint")
public class GatewayVpcEndpoint extends software.amazon.awscdk.services.ec2.VpcEndpoint implements software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint {
    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public GatewayVpcEndpoint(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint fromGatewayVpcEndpointId(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final java.lang.String gatewayVpcEndpointId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.GatewayVpcEndpoint.class, "fromGatewayVpcEndpointId", software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(gatewayVpcEndpointId, "gatewayVpcEndpointId is required") });
    }

    /**
     * The date and time the gateway VPC endpoint was created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointCreationTimestamp() {
        return this.jsiiGet("vpcEndpointCreationTimestamp", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointDnsEntries() {
        return this.jsiiGet("vpcEndpointDnsEntries", java.util.List.class);
    }

    /**
     * The gateway VPC endpoint identifier.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointId() {
        return this.jsiiGet("vpcEndpointId", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointNetworkInterfaceIds() {
        return this.jsiiGet("vpcEndpointNetworkInterfaceIds", java.util.List.class);
    }
}

==> ec2-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/GatewayVpcEndpoint.java <==
package software.amazon.awscdk.services.ec2;

/**
 * A gateway VPC endpoint.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:50:03.197Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.GatewayVpcEndpoint")
public class GatewayVpcEndpoint extends software.amazon.awscdk.services.ec2.VpcEndpoint implements software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint {

    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected GatewayVpcEndpoint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public GatewayVpcEndpoint(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.GatewayVpcEndpointProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint fromGatewayVpcEndpointId(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final java.lang.String gatewayVpcEndpointId) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.GatewayVpcEndpoint.class, "fromGatewayVpcEndpointId", software.amazon.awscdk.services.ec2.IGatewayVpcEndpoint.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(gatewayVpcEndpointId, "gatewayVpcEndpointId is required") });
    }

    /**
     * The date and time the gateway VPC endpoint was created.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointCreationTimestamp() {
        return this.jsiiGet("vpcEndpointCreationTimestamp", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointDnsEntries() {
        return this.jsiiGet("vpcEndpointDnsEntries", java.util.List.class);
    }

    /**
     * The gateway VPC endpoint identifier.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getVpcEndpointId() {
        return this.jsiiGet("vpcEndpointId", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getVpcEndpointNetworkInterfaceIds() {
        return this.jsiiGet("vpcEndpointNetworkInterfaceIds", java.util.List.class);
    }
}
